@@ -5,14 +5,14 @@
  * Base URL Parameters:
  *   - page: (string) The current page view.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -26,7 +26,8 @@ Horde_Registry::appInit('imp', array(
 
 $class = 'IMP_Dynamic_' . Horde_String::ucfirst($vars->page);
 if (!class_exists($class)) {
-    throw new IMP_Exception('Page not found: ' . $vars->page);
+    /* Need to do redirect to ensure that browser URL is updated. */
+    IMP::getInitialPage()->url->redirect();
 }
 
 $ob = new $class($vars);
