@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -17,7 +17,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -78,6 +78,9 @@ class IMP_Ajax_Application_Handler_Common extends Horde_Core_Ajax_Application_Ha
                 isset($vp_vars->sortby) ? $vp_vars->sortby : null,
                 isset($vp_vars->sortdir) ? $vp_vars->sortdir : null
             );
+
+            /* Ensure that results are updated for search mailboxes. */
+            $this->vars->forceUpdate = true;
         }
 
         /* Toggle hide deleted preference if necessary. */
@@ -104,10 +107,6 @@ class IMP_Ajax_Application_Handler_Common extends Horde_Core_Ajax_Application_Ha
             try {
                 $vp = $this->_base->viewPortData($changed);
                 $result = true;
-
-                if (isset($vp_vars->delhide)) {
-                    $vp->metadata_reset = 1;
-                }
             } catch (Exception $e) {
                 $vp = new IMP_Ajax_Application_Viewport_Error($this->_base->indices->mailbox);
             }
@@ -593,7 +592,7 @@ class IMP_Ajax_Application_Handler_Common extends Horde_Core_Ajax_Application_Ha
             } else {
                 /* Don't push notification if showing passphrase dialog -
                  * passphrase dialog contains the necessary information. */
-                $notification->push($e);
+                $notification->push($e, $notify_level);
             }
 
             return $result;
