@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -832,7 +832,11 @@ extends Horde_Core_Ajax_Application_Handler
      *
      * @return mixed  False on failure, or an object with these properties:
      *   - buid: (integer) BUID of message.
-     *   - mbox: (string) Mailbox of message (base64url encoded).
+     *   - mbox: (string) Mailbox of message (base64url encoded). Only
+     *           returned if view is a search mailbox.
+     *   - uid: (string) Mailbox of message (base64url encoded). Only
+     *          returned if view is a search mailbox.
+     *   - view: (string) The view ID.
      */
     public function sendMDN()
     {
@@ -858,9 +862,17 @@ extends Horde_Core_Ajax_Application_Handler
 
         $notification->push(_("The Message Disposition Notification was sent successfully."), 'horde.success');
 
+        list($view, $buid) = $this->_base->indices->buids->getSingle();
+        list($mbox, $uid) = $this->_base->indices->getSingle();
+
         $result = new stdClass;
-        $result->buid = $this->_base->vars->buid;
-        $result->mbox = $mbox->form_to;
+        $result->buid = $buid;
+        $result->view = $view->form_to;
+
+        if ($view != $mbox) {
+            $result->mbox = $mbox->form_to;
+            $result->uid = $uid;
+        }
 
         return $result;
     }
