@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2005-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2005-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2005-2014 Horde LLC
+ * @copyright 2005-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2005-2014 Horde LLC
+ * @copyright 2005-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -163,11 +163,10 @@ class IMP_Ajax_Application_ListMessages
         }
 
         /* Mail-specific viewport information. */
-        if (($args['initial'] ||
-             $args['delhide'] ||
-             !is_null($args['sortby'])) &&
-            $mbox->hideDeletedMsgs(true)) {
-            $result->setMetadata('delhide', 1);
+        if ($args['initial'] ||
+            (isset($args['delhide']) && !is_null($args['delhide'])) ||
+            !is_null($args['sortby']))  {
+            $result->setMetadata('delhide', $mbox->hideDeletedMsgs(true));
         }
         if ($args['initial'] ||
             !is_null($args['sortby']) ||
