@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -57,7 +57,7 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
      */
     protected function _handle(Horde_Variables $vars)
     {
-        global $conf, $injector, $notification, $registry;
+        global $injector, $notification, $registry;
 
         $actions = (array)$vars->imple_submit;
         $result = false;
@@ -240,13 +240,7 @@ class IMP_Ajax_Imple_ItipRequest extends Horde_Core_Ajax_Imple
                         // Send the reply.
                         Horde_Itip::factory($vEvent, $resource)->sendMultiPartResponse(
                             $type,
-                            new Horde_Itip_Response_Options_Horde(
-                                'UTF-8',
-                                array(
-                                    'dns' => $injector->getInstance('Net_DNS2_Resolver'),
-                                    'server' => $conf['server']['name']
-                                )
-                            ),
+                            new Horde_Core_Itip_Response_Options_Horde('UTF-8', array()),
                             $injector->getInstance('IMP_Mail')
                         );
                         $notification->push(_("Reply Sent."), 'horde.success');
