@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -38,7 +38,7 @@ require_once HORDE_BASE . '/lib/core.php';
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -66,7 +66,7 @@ class IMP_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (6.2.2)';
+    public $version = 'H5 (6.2.10)';
 
     /**
      * Server key used in logged out session.
@@ -472,7 +472,14 @@ class IMP_Application extends Horde_Registry_Application
      */
     public function changeLanguage()
     {
-        $GLOBALS['injector']->getInstance('IMP_Ftree')->init();
+        global $injector;
+
+        $injector->getInstance('IMP_Mailbox_SessionCache')->expire(array(
+            IMP_Mailbox_SessionCache::CACHE_DISPLAY,
+            IMP_Mailbox_SessionCache::CACHE_LABEL
+        ));
+
+        $injector->getInstance('IMP_Ftree')->init();
     }
 
     /* NoSQL methods. */
