@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -17,7 +17,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -107,6 +107,11 @@ class IMP_Basic_Contacts extends IMP_Basic_Base
         $page_output->addScriptFile('contacts.js');
         $page_output->addInlineJsVars(array(
             'ImpContacts.text' => array(
+                'rcpt' => array(
+                    'to' => _("To"),
+                    'cc' => _("Cc"),
+                    'bcc' => _("Bcc")
+                ),
                 'closed' => _("The message being composed has been closed."),
                 'select' => _("You must select an address first.")
             )
