@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -17,7 +17,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -160,7 +160,7 @@ class IMP_Crypt_Pgp extends Horde_Crypt_Pgp
              * address book and remove the id from the key_info for a correct
              * output. */
             try {
-                $result = $this->getPublicKey($sig['email'], array('nocache' => true, 'noserver' => true));
+                $result = $this->getPublicKey($sig['email'], array('nocache' => true, 'noserver' => true, 'nohooks' => true));
                 if (!empty($result)) {
                     unset($key_info['signature'][$id]);
                     continue;
@@ -213,16 +213,18 @@ class IMP_Crypt_Pgp extends Horde_Crypt_Pgp
             }
         }
 
-        try {
-            $key = $injector->getInstance('Horde_Core_Hooks')->callHook(
-                'pgp_key',
-                'imp',
-                array($address, $keyid)
-            );
-            if ($key) {
-                return $key;
-            }
-        } catch (Horde_Exception_HookNotSet $e) {}
+        if (empty($options['nohooks'])) {
+            try {
+                $key = $injector->getInstance('Horde_Core_Hooks')->callHook(
+                    'pgp_key',
+                    'imp',
+                    array($address, $keyid)
+                );
+                if ($key) {
+                    return $key;
+                }
+            } catch (Horde_Exception_HookNotSet $e) {}
+        }
 
         /* Try retrieving by e-mail only first. */
         $params = $injector->getInstance('IMP_Contacts')->getAddressbookSearchParams();
