@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2014 Horde LLC
+ * @copyright 2012-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -133,6 +133,8 @@ class IMP_Dynamic_Mailbox extends IMP_Dynamic_Base
         $imp_imap = $injector->getInstance('IMP_Factory_Imap')->create();
         $acl = $imp_imap->access(IMP_Imap::ACCESS_ACL);
 
+        $subscribe = $prefs->getValue('subscribe');
+
         $this->js_conf += array_filter(array(
             // URLs
             'URI_LISTINFO' => strval(IMP_Basic_Listinfo::url()->setRaw(true)),
@@ -211,7 +213,8 @@ class IMP_Dynamic_Mailbox extends IMP_Dynamic_Base
                     't' => _("Size"),
                     'v' => Horde_Imap_Client::SORT_SIZE
                 )
-            )
+            ),
+            'subscribe' => intval($subscribe)
         ));
 
         $context = array(
@@ -293,7 +296,6 @@ class IMP_Dynamic_Mailbox extends IMP_Dynamic_Base
             );
         }
 
-        $subscribe = $prefs->getValue('subscribe');
         if (!$subscribe) {
             unset(
                 $context['ctx_folderopts']['sub'],
@@ -409,6 +411,12 @@ class IMP_Dynamic_Mailbox extends IMP_Dynamic_Base
                 $context['ctx_mbox']['search']
             );
         }
+        if (!$imp_imap->access(IMP_Imap::ACCESS_FLAGS) ||
+            $prefs->isLocked('acl')) {
+            unset(
+                $context['ctx_mbox']['_sub2']
+            );
+        }
 
         /* Other Actions context menu. */
         $context['ctx_oa'] = array(
