@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -67,10 +67,12 @@ class IMP_Factory_Imap extends Horde_Core_Factory_Base implements Horde_Shutdown
             } catch (Exception $e) {
                 // This indicates an unserialize() error.  This is fatal, so
                 // logout.
-                throw new Horde_Exception_AuthenticationFailure(
+                $failure = new Horde_Exception_AuthenticationFailure(
                     'Cached IMP session data has become invalid; expiring session.',
                     Horde_Auth::REASON_SESSION
                 );
+                $failure->application = 'imp';
+                throw $failure;
             }
 
             if (!is_object($ob)) {
