@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2000-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2000-2014 Horde LLC
+ * @copyright 2000-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -21,7 +21,7 @@
  * @author    Jon Parise <jon@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2000-2014 Horde LLC
+ * @copyright 2000-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  *
@@ -460,7 +460,7 @@ implements ArrayAccess, Countable, IteratorAggregate, Serializable
         $old_track = $this->eltdiff->track;
         $this->eltdiff->track = false;
         foreach ($this->_accounts as $val) {
-            array_map(array($this, '_insertElt'), $val->getList(null, $val::UNSUB));
+            array_map(array($this, '_insertElt'), $val->getList(array(), $val::UNSUB));
         }
         $this->eltdiff->track = $old_track;
     }
@@ -770,7 +770,7 @@ implements ArrayAccess, Countable, IteratorAggregate, Serializable
 
         $change = false;
         if (isset($this->_elts[$name])) {
-            if ($elt['a'] && self::ELT_NOSELECT) {
+            if ($elt['a'] & self::ELT_NOSELECT) {
                 return;
             }
             $change = true;
@@ -784,7 +784,9 @@ implements ArrayAccess, Countable, IteratorAggregate, Serializable
         if (!isset($this->_parent[$parent])) {
             $this->eltdiff->change($p_elt);
         }
-        $this->_parent[$parent][] = $name;
+        if (!isset($this->_elts[$name])) {
+            $this->_parent[$parent][] = $name;
+        }
         $this->_elts[$name] = $elt['a'];
 
         if ($change) {
