@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2008-2014 Horde LLC
+ * @copyright 2008-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -17,7 +17,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2008-2014 Horde LLC
+ * @copyright 2008-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  *
@@ -717,9 +717,13 @@ class IMP_Imap implements Serializable
         try {
             $result = call_user_func_array(array($this->_ob, $method), $params);
         } catch (Horde_Imap_Client_Exception $e) {
-            switch ($method) {
-            case 'getNamespaces':
-                return new Horde_Imap_Client_Namespace_List();
+            $error = new IMP_Imap_Exception($e);
+
+            if (!$error->authError()) {
+                switch ($method) {
+                case 'getNamespaces':
+                    return new Horde_Imap_Client_Namespace_List();
+                }
             }
 
             Horde::log(
@@ -730,10 +734,8 @@ class IMP_Imap implements Serializable
                 ),
                 'WARN'
             );
-            $error = new IMP_Imap_Exception($e);
-            throw ($auth_e = $error->authException(false))
-                ? $auth_e
-                : $error;
+
+            throw $error;
         }
 
         /* Special handling for various methods. */
