@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2011-2014 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2011-2014 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  *
@@ -53,43 +53,45 @@ class IMP_Imap_Exception extends Horde_Imap_Client_Exception
     /**
      * Generates an authentication exception.
      *
-     * @param boolean $default  Return exception, even if no code exists?
-     *
      * @return Horde_Auth_Exception  An authentication exception.
      */
-    public function authException($default = true)
+    public function authException()
+    {
+        $code = $this->authError();
+
+        return new Horde_Auth_Exception(
+            $this,
+            is_null($code) ? Horde_Auth::REASON_FAILED : $code
+        );
+    }
+
+    /**
+     * Returns the authentication error, if any.
+     *
+     * @return integer  Authentication error, or null if exception not caused
+     *                  by auth error.
+     */
+    public function authError()
     {
         switch ($this->getCode()) {
         case self::LOGIN_AUTHENTICATIONFAILED:
         case self::LOGIN_AUTHORIZATIONFAILED:
-            $code = Horde_Auth::REASON_BADLOGIN;
-            break;
+            return Horde_Auth::REASON_BADLOGIN;
 
         case self::LOGIN_EXPIRED:
-            $code = Horde_Auth::REASON_EXPIRED;
-            break;
+            return Horde_Auth::REASON_EXPIRED;
 
         case self::SERVER_CONNECT:
         case self::LOGIN_UNAVAILABLE:
-            $code = Horde_Auth::REASON_MESSAGE;
-            break;
+            return Horde_Auth::REASON_MESSAGE;
 
         case self::LOGIN_NOAUTHMETHOD:
         case self::LOGIN_PRIVACYREQUIRED:
         case self::LOGIN_TLSFAILURE:
-            $code = Horde_Auth::REASON_FAILED;
-            break;
-
-        default:
-            $code = $default
-                ? Horde_Auth::REASON_FAILED
-                : null;
-            break;
+            return Horde_Auth::REASON_FAILED;
         }
 
-        return is_null($code)
-            ? null
-            : new Horde_Auth_Exception($this, $code);
+        return null;
     }
 
     /**
