@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -76,11 +76,23 @@ class IMP_Imap_Password implements Horde_Imap_Client_Base_Password, Serializable
     }
 
     /**
+     * @throws RuntimeException
      */
     public function unserialize($data)
     {
         $this->_id = $data;
-        $this->_password = $GLOBALS['session']->get('imp', self::PASSWORD_KEY . '/' . $this->_id);
+
+        $password = $GLOBALS['session']->get(
+            'imp',
+            self::PASSWORD_KEY . '/' . $this->_id
+        );
+        if (!strlen($password)) {
+            /* Without a password, this object is invalid. */
+            throw new RuntimeException(
+                'Invalid object since password is empty.'
+            );
+        }
+        $this->_password = $password;
     }
 
 }
