@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013-2014 Horde LLC
+ * @copyright 2013-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -59,7 +59,10 @@ class IMP_Indices_Mailbox extends IMP_Indices
                     $this->mailbox = IMP_Mailbox::formFrom($args[0]->mailbox);
 
                     if (isset($args[0]->buid)) {
-                        $this->buids = new IMP_Indices($this->mailbox, $args[0]->buid);
+                        /* BUIDs are always integers. Do conversion here since
+                         * POP3 won't work otherwise. */
+                        $tmp = new Horde_Imap_Client_Ids($args[0]->buid);
+                        $this->buids = new IMP_Indices($this->mailbox, $tmp->ids);
                         parent::__construct($this->mailbox->fromBuids($this->buids));
                     } elseif (isset($args[0]->uid)) {
                         parent::__construct($this->mailbox, $args[0]->uid);
