@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2011-2014 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2011-2014 Horde LLC
+ * @copyright 2011-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  *
@@ -1426,7 +1426,7 @@ class IMP_Mailbox
         global $injector;
 
         $cache = $injector->getInstance('IMP_Mailbox_SessionCache');
-        $mbox_str = strval($mbox);
+        $mbox_str = $ret = strval($mbox);
 
         if (($pref_to = $cache->getPrefTo($mbox_str)) !== false) {
             return $pref_to;
@@ -1472,6 +1472,8 @@ class IMP_Mailbox
      */
     protected function _getCacheID($date = false)
     {
+        global $prefs;
+
         $date = $date
             ? 'D' . date('z')
             : '';
@@ -1481,7 +1483,11 @@ class IMP_Mailbox
         }
 
         $sortpref = $this->getSort(true);
-        $addl = array($sortpref->sortby, $sortpref->sortdir);
+        $addl = array(
+            $sortpref->sortby,
+            $sortpref->sortdir,
+            intval($prefs->getValue('delhide'))
+        );
         if ($date) {
             $addl[] = $date;
         }
