@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 1999-2014 Horde LLC
+ * @copyright 1999-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -18,7 +18,7 @@
  * @author    Jon Parise <jon@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 1999-2014 Horde LLC
+ * @copyright 1999-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -257,7 +257,9 @@ class IMP_Mime_Viewer_Html extends Horde_Mime_Viewer_Html
                      * within image blocking if possible. */
                     $tmp = new IMP_Mime_Status(array(
                         _("Message styling has been suppressed in this message part since the style data lives on a remote server."),
-                        Horde::link('#', '', $class) . _("Load Styling?") . '</a>'
+                        Horde::link('#', '', $class, '', '', '', '', array(
+                            'muid' => strval($contents->getIndicesOb())
+                        )) . _("Load Styling?") . '</a>'
                     ));
                     $tmp->icon('mime/image.png');
                     $status[] = $tmp;
@@ -672,7 +674,9 @@ class IMP_Mime_Viewer_Html extends Horde_Mime_Viewer_Html
     protected function _imgBlockImg()
     {
         if (!isset($this->_imptmp['blockimg'])) {
-            $this->_imptmp['blockimg'] = strval(Horde_Themes::img('spacer_red.png'));
+            /* Need full URL here because a <base> tag may change the root
+             * of relative URLs. */
+            $this->_imptmp['blockimg'] = Horde_Themes::img('spacer_red.png')->fulluri;
         }
 
         return $this->_imptmp['blockimg'];
