@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -20,7 +20,7 @@
  * @author    Michael Slusarz <slusarz@horde.org>
  * @author    Gunnar Wrobel <wrobel@pardus.de>
  * @category  Horde
- * @copyright 2002-2014 Horde LLC
+ * @copyright 2002-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -118,16 +118,18 @@ class IMP_Mime_Viewer_Itip extends Horde_Mime_Viewer_Base
         }
 
         $out = array();
+        $exceptions = array();
         $components = $vCal->getComponents();
         foreach ($components as $key => $component) {
             switch ($component->getType()) {
             case 'vEvent':
                 try {
                     if ($component->getAttribute('RECURRENCE-ID')) {
-                        break;
+                        $exceptions[] = $this->_vEvent($component, $key, $method, $components);
                     }
-                } catch (Horde_ICalendar_Exception $e) {}
-                $out[] = $this->_vEvent($component, $key, $method, $components);
+                } catch (Horde_ICalendar_Exception $e) {
+                    $out[] = $this->_vEvent($component, $key, $method, $components);
+                }
                 break;
 
             case 'vTodo':
@@ -149,6 +151,13 @@ class IMP_Mime_Viewer_Itip extends Horde_Mime_Viewer_Base
             }
         }
 
+        // If we don't have any other parts, any exceptions should be shown
+        // since this is likely an update to a series instance such as a
+        // cancellation etc...
+        if (empty($out)) {
+            $out = $exceptions;
+        }
+
         $view = $this->_getViewOb();
         $view->formid = $imple->getDomId();
         $view->out = implode('', $out);
@@ -707,7 +716,7 @@ class IMP_Mime_Viewer_Itip extends Horde_Mime_Viewer_Base
             if (!is_array($attendees)) {
                 $attendees = array($attendees);
             }
-            $view->attendees = $this->parseAttendees($vtodo, $attendees);
+            $view->attendees = $this->_parseAttendees($vtodo, $attendees);
         }
 
         if (!empty($options)) {
