@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2010-2013 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2010-2013 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -28,18 +28,14 @@ extends Horde_Core_Notification_Handler_Decorator_Base
     protected $_app = 'imp';
 
     /**
-     * Listeners are handling their messages.
-     *
-     * @param Horde_Notification_Handler  $handler   The base handler object.
-     * @param Horde_Notification_Listener $listener  The Listener object that
-     *                                               is handling its messages.
      */
-    public function notify(Horde_Notification_Handler $handler,
-                           Horde_Notification_Listener $listener)
+    protected function _notify(
+        Horde_Notification_Handler $handler,
+        Horde_Notification_Listener $listener
+    )
     {
         if (($listener instanceof Horde_Notification_Listener_Status) &&
-            ($ob = $GLOBALS['injector']->getInstance('IMP_Imap')) &&
-            $ob->init) {
+            ($ob = $GLOBALS['injector']->getInstance('IMP_Factory_Imap'))) {
             /* Display IMAP alerts. */
             foreach ($ob->alerts() as $alert) {
                 $handler->push($alert, 'horde.warning');
