@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -17,7 +17,7 @@
  * @author    Jan Schneider <jan@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2010-2014 Horde LLC
+ * @copyright 2010-2015 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -103,8 +103,11 @@ class IMP_Sentmail_Sql extends IMP_Sentmail
     public function numberOfRecipients($hours, $user = false)
     {
         /* Build the SQL query. */
-        $query = sprintf('SELECT COUNT(*) FROM %s WHERE sentmail_ts > ?',
-                         $this->_params['table']);
+        $query = sprintf(
+            'SELECT COUNT(*) FROM %s WHERE sentmail_ts > ? AND sentmail_success = 1',
+            $this->_params['table']
+        );
+
         if ($user) {
             $query .= sprintf(' AND sentmail_who = %s', $this->_db->quote($GLOBALS['registry']->getAuth()));
         }
