@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category   Horde
- * @copyright  2010-2014 Horde LLC
+ * @copyright  2010-2015 Horde LLC
  * @license    http://www.horde.org/licenses/gpl GPL
  * @package    IMP
  * @subpackage UnitTests
@@ -18,7 +18,7 @@
  * @author     Michael Slusarz <slusarz@horde.org>
  * @author     Gunnar Wrobel <wrobel@pardus.de>
  * @category   Horde
- * @copyright  2010-2014 Horde LLC
+ * @copyright  2010-2015 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/gpl GPL
  * @package    IMP
@@ -54,6 +54,9 @@ extends PHPUnit_Framework_TestCase
         $registry->expects($this->any())
             ->method('getCharset')
             ->will($this->returnValue('UTF-8'));
+        $registry->expects($this->any())
+            ->method('remoteHost')
+            ->will($this->returnValue((object)array('addr' => '1.2.3.4', 'host' => 'example.com', 'proxy' => false)));
         $GLOBALS['registry'] = $registry;
 
         $notification = $this->getMock('Horde_Notification_Handler', array(), array(), '', false);
